#ifndef UPNPSTATEVARREQUEST_H
#define UPNPSTATEVARREQUEST_H

/*!
 * \file
 *
 * \brief Header file for UpnpStateVarRequest methods.
 *
 * Do not edit this file, it is automatically generated. Please look at
 * generator.c.
 *
 * \author Marcelo Roberto Jimenez
 */
#include <stdlib.h> /* for size_t */

#include "UpnpGlobal.h" /* for UPNP_EXPORT_SPEC */

#include "UpnpInet.h"
#include "UpnpString.h"
#include "ixml.h"

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*!
 * UpnpStateVarRequest
 */
typedef struct s_UpnpStateVarRequest UpnpStateVarRequest;

/*! Constructor */
UPNP_EXPORT_SPEC UpnpStateVarRequest *UpnpStateVarRequest_new(void);
/*! Destructor */
UPNP_EXPORT_SPEC void UpnpStateVarRequest_delete(UpnpStateVarRequest *p);
/*! Copy Constructor */
UPNP_EXPORT_SPEC UpnpStateVarRequest *UpnpStateVarRequest_dup(
	const UpnpStateVarRequest *p);
/*! Assignment operator */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_assign(
	UpnpStateVarRequest *p, const UpnpStateVarRequest *q);

/*! UpnpStateVarRequest_get_ErrCode */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_get_ErrCode(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_set_ErrCode */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_ErrCode(
	UpnpStateVarRequest *p, int n);

/*! UpnpStateVarRequest_get_Socket */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_get_Socket(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_set_Socket */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_Socket(
	UpnpStateVarRequest *p, int n);

/*! UpnpStateVarRequest_get_ErrStr */
UPNP_EXPORT_SPEC const UpnpString *UpnpStateVarRequest_get_ErrStr(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_set_ErrStr */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_ErrStr(
	UpnpStateVarRequest *p, const UpnpString *s);
/*! UpnpStateVarRequest_get_ErrStr_Length */
UPNP_EXPORT_SPEC size_t UpnpStateVarRequest_get_ErrStr_Length(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_get_ErrStr_cstr */
UPNP_EXPORT_SPEC const char *UpnpStateVarRequest_get_ErrStr_cstr(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_strcpy_ErrStr */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strcpy_ErrStr(
	UpnpStateVarRequest *p, const char *s);
/*! UpnpStateVarRequest_strncpy_ErrStr */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strncpy_ErrStr(
	UpnpStateVarRequest *p, const char *s, size_t n);
/*! UpnpStateVarRequest_clear_ErrStr */
UPNP_EXPORT_SPEC void UpnpStateVarRequest_clear_ErrStr(UpnpStateVarRequest *p);

/*! UpnpStateVarRequest_get_DevUDN */
UPNP_EXPORT_SPEC const UpnpString *UpnpStateVarRequest_get_DevUDN(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_set_DevUDN */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_DevUDN(
	UpnpStateVarRequest *p, const UpnpString *s);
/*! UpnpStateVarRequest_get_DevUDN_Length */
UPNP_EXPORT_SPEC size_t UpnpStateVarRequest_get_DevUDN_Length(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_get_DevUDN_cstr */
UPNP_EXPORT_SPEC const char *UpnpStateVarRequest_get_DevUDN_cstr(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_strcpy_DevUDN */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strcpy_DevUDN(
	UpnpStateVarRequest *p, const char *s);
/*! UpnpStateVarRequest_strncpy_DevUDN */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strncpy_DevUDN(
	UpnpStateVarRequest *p, const char *s, size_t n);
/*! UpnpStateVarRequest_clear_DevUDN */
UPNP_EXPORT_SPEC void UpnpStateVarRequest_clear_DevUDN(UpnpStateVarRequest *p);

/*! UpnpStateVarRequest_get_ServiceID */
UPNP_EXPORT_SPEC const UpnpString *UpnpStateVarRequest_get_ServiceID(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_set_ServiceID */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_ServiceID(
	UpnpStateVarRequest *p, const UpnpString *s);
/*! UpnpStateVarRequest_get_ServiceID_Length */
UPNP_EXPORT_SPEC size_t UpnpStateVarRequest_get_ServiceID_Length(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_get_ServiceID_cstr */
UPNP_EXPORT_SPEC const char *UpnpStateVarRequest_get_ServiceID_cstr(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_strcpy_ServiceID */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strcpy_ServiceID(
	UpnpStateVarRequest *p, const char *s);
/*! UpnpStateVarRequest_strncpy_ServiceID */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strncpy_ServiceID(
	UpnpStateVarRequest *p, const char *s, size_t n);
/*! UpnpStateVarRequest_clear_ServiceID */
UPNP_EXPORT_SPEC void UpnpStateVarRequest_clear_ServiceID(
	UpnpStateVarRequest *p);

/*! UpnpStateVarRequest_get_StateVarName */
UPNP_EXPORT_SPEC const UpnpString *UpnpStateVarRequest_get_StateVarName(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_set_StateVarName */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_StateVarName(
	UpnpStateVarRequest *p, const UpnpString *s);
/*! UpnpStateVarRequest_get_StateVarName_Length */
UPNP_EXPORT_SPEC size_t UpnpStateVarRequest_get_StateVarName_Length(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_get_StateVarName_cstr */
UPNP_EXPORT_SPEC const char *UpnpStateVarRequest_get_StateVarName_cstr(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_strcpy_StateVarName */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strcpy_StateVarName(
	UpnpStateVarRequest *p, const char *s);
/*! UpnpStateVarRequest_strncpy_StateVarName */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_strncpy_StateVarName(
	UpnpStateVarRequest *p, const char *s, size_t n);
/*! UpnpStateVarRequest_clear_StateVarName */
UPNP_EXPORT_SPEC void UpnpStateVarRequest_clear_StateVarName(
	UpnpStateVarRequest *p);

/*! UpnpStateVarRequest_get_CtrlPtIPAddr */
UPNP_EXPORT_SPEC const struct sockaddr_storage *
UpnpStateVarRequest_get_CtrlPtIPAddr(const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_get_CtrlPtIPAddr */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_CtrlPtIPAddr(
	UpnpStateVarRequest *p, const struct sockaddr_storage *buf);
/*! UpnpStateVarRequest_get_CtrlPtIPAddr */
UPNP_EXPORT_SPEC void UpnpStateVarRequest_clear_CtrlPtIPAddr(
	UpnpStateVarRequest *p);

/*! UpnpStateVarRequest_get_CurrentVal */
UPNP_EXPORT_SPEC const DOMString UpnpStateVarRequest_get_CurrentVal(
	const UpnpStateVarRequest *p);
/*! UpnpStateVarRequest_set_CurrentVal */
UPNP_EXPORT_SPEC int UpnpStateVarRequest_set_CurrentVal(
	UpnpStateVarRequest *p, const DOMString s);
/*! UpnpStateVarRequest_get_CurrentVal_cstr */
UPNP_EXPORT_SPEC const char *UpnpStateVarRequest_get_CurrentVal_cstr(
	const UpnpStateVarRequest *p);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* UPNPSTATEVARREQUEST_H */
